# Third-party includes

## JSON library `nlohmann/json`
Place `nlohmann/json` headers in `nlohmann` folder.  
Current version: 3.10.5 (4f8fba14066156b73f1189a2b8bd568bde5284c5)

## Format library `fmtlib/fmt`
Place `fmtlib/fmt` headers in `fmt` folder.  
Current version: 8.1.1 (b6f4ceaed0a0a24ccf575fab6c56dd50ccf6f1a9)
